##########
django CMS
##########

A Django application for managing hierarchical pages of content, possibly in
multiple languages and/or on multiple sites.

Django CMS handles the navigation rendering for you with clean, slug based URLs,
and this navigation can be extended by custom Django applications

You can define editable areas, called placeholders, in your templates which you
can fill with CMS plugins, by default we ship the following plugins:

* File
* Flash
* Google Map
* Link
* Picture
* HTML Snippet
* Teaser
* Text
* Video
* Twitter

However this is not the end of the list, there are many
`3rd party plugins <http://www.djangopackages.com/grids/g/django-cms/>`_ 
already available for you to use. Should you be unable to find a suitable plugin
for you needs, writing your own is very simple.

More information on `our website <http://www.django-cms.org>`_. 

*************
Documentation
*************

Please head over to our `documentation <http://docs.django-cms.org/>`_ for all
the details on how to install, extend and use the django CMS.

************
Getting Help
************

Please head over to our IRC channel, #django-cms, on irc.freenode.net or write
to our `mailing list <https://groups.google.com/forum/#!forum/django-cms>`_.

*******
Credits
*******

* This is a fork of the
  `django-page-cms <https://github.com/batiste/django-page-cms>`_.
* Includes icons from `FamFamFam <http://www.famfamfam.com>`_.
* Video plugin uses the
  `OSFlashVideoPlayer <https://github.com/FlashJunior/OSFlashVideoPlayer/>`_.
* Includes the `Wymeditor <http://www.wymeditor.org/>`_.
* Python tree engine powered by
  `django-mptt <https://github.com/django-mptt/django-mptt>`_.
* Javascript tree in admin uses `jsTree <http://www.jstree.com>`_.
* Many thanks to the
  `over 150 contributors <https://github.com/divio/django-cms/blob/master/AUTHORS>`_
  to the django CMS!